/* compile with: cmex digamma.c util.c -lm
 * test in matlab:
 *   digamma(1:10)
 */
#define V4_COMPAT
#include "mex.h"
#include "util.h"

void mexFunction(int nlhs, Matrix *plhs[],
		 int nrhs, Matrix *prhs[])
{
  int rows, cols, len, i;
  double *indata, *outdata;

  if((nrhs != 1) || (nrhs > 1))    
    mexErrMsgTxt("Usage: x = digamma(n)");

  /* prhs[0] is first argument.
   * mxGetPr returns double*  (data, col-major)
   * mxGetM returns int  (rows)
   * mxGetN returns int  (cols)
   */
  rows = mxGetM(prhs[0]);
  cols = mxGetN(prhs[0]);
  indata = mxGetPr(prhs[0]);
  len = rows*cols;

  if(mxIsSparse(prhs[0]))
    mexErrMsgTxt("Cannot handle sparse matrices.  Sorry.");

  /* plhs[0] is first output */
  plhs[0] = mxCreateFull(rows, cols, REAL);
  outdata = mxGetPr(plhs[0]);

  /* compute digamma of every element */
  for(i=0;i<len;i++)
    *outdata++ = digamma(*indata++);
}

